@@ -59,10 +59,12 @@ C
 cc      PARAMETER (LMAX=500)
 cc      PARAMETER (MMAX=50)
 cc      PARAMETER (NMAX=25)
-      PARAMETER (ICST=190)
+cxxx      PARAMETER (ICST=190)
+      INTEGER, PARAMETER :: ICST=190
 C
 cxx      IMPLICIT REAL*8(A-H,O-Z)
 cc      COMMON /COM50/VD
+      INTEGER ISWRO, IDOS, ISIK
       COMMON /COM70/ISWRO
       COMMON /COM71/IDOS
       COMMON /COM72/ISIK
@@ -93,13 +95,16 @@ cxx      DIMENSION A1(IPI1(1)),B1(IQI1(1))
 cxx      DIMENSION IP(NMAX),IQ(NMAX),IPO(NMAX),IQO(NMAX)
 cxx      DIMENSION A2(MMAX,NMAX),B2(MMAX,NMAX)
 cxx      DIMENSION SMAIC2(NMAX),CXX2(NMAX)
-      INTEGER N, LAGH01, NEWL1, IQI1(NEWL1), IPI1(NEWL1), NEWN,
-     1        IQ(NMAX), IP(NMAX), KQ, KP, LMAX, MMAX, NMAX
+      INTEGER N, LAGH01, NEWL1, NEWN, KQ, KP, LMAX, MMAX, NMAX,
+     1        IQI1(NEWL1), IPI1(NEWL1), IQ(NMAX), IP(NMAX)
       DOUBLE PRECISION CYY1(LAGH01), A1(IPI1(1)), B1(IQI1(1)),
      1                 A2(MMAX,NMAX), B2(MMAX,NMAX), STD(MMAX,NMAX),
      2                 CXX2(NMAX), G(MMAX,NMAX), SAIC(NMAX), AICM
 c local
-      INTEGER IQI(NMAX), IPI(NMAX), IPO(NMAX), IQO(NMAX)
+      INTEGER I, II, IIM, IIP, IB, IG, IDE, IDO, IPQ, IPM1, IQM1, ISFIN,
+     1        J, JP, JP1, JPO, JQ, JQ1, JQO, LAGH, LAGH1, LAGH2, LAGH4, 
+     2        NEWL, NEWLM1,
+     2        IQI(NMAX), IPI(NMAX), IPO(NMAX), IQO(NMAX)
       DOUBLE PRECISION CYY(LMAX*2+1), A(MMAX), B(MMAX), OA(MMAX),
      1                 OB(MMAX), X(MMAX), C(MMAX), CC(ICST),
      2                 VD(MMAX,MMAX), CN(MMAX+1), SMAIC2(NMAX), CST0,
@@ -648,6 +653,7 @@ cxx      SUBROUTINE SC0GRH(X,CYY,G,CN,CXX0,IP,IQ,AL,MM,LL,ICST,IFG,LU)
 C     THIS SUBROUTINE COMPUTES CXX0,GRADIENT AND HESSIAN.
 cxx      IMPLICIT REAL*8(A-H,O-Z)
 cc      COMMON /COM50/AL
+      INTEGER ISWRO, IDOS, ISIK
       COMMON /COM70/ISWRO
       COMMON /COM71/IDOS
       COMMON /COM72/ISIK
@@ -679,9 +685,14 @@ cc      EQUIVALENCE (CZY(1),CZZ(1))
 cc      EQUIVALENCE (CYU(1),CYZ(1),CZX(1))
 c
       INTEGER IP, IQ, MM, LL, ICST
-      DOUBLE PRECISION X(IP+IQ), CYY(LL*2+1), G(IP+I Q), CN(MM+1),
+      DOUBLE PRECISION X(IP+IQ), CYY(LL*2+1), G(IP+IQ), CN(MM+1),
      1                 CXX0, AL(MM,MM)
 c local
+      INTEGER I, II, IA, IJ, IJ1, IEN, IK, IG, I1, I2P, IAIB, IA2B,
+     1        IORIG, IPM1, IQM1, IST, J, JJ, L2, LUU, LUX, LUY, LUYU,
+     2        LUYZ, LUZ, LXX, LXY, LYU, LYX, LYZ, LZX, LZY, LZYZ, LZZ,
+     3        M2, MUU, MUX, MUY, MUYU, MUYZ, MUZ, MXX, MXY, MYU, MYX,
+     4        MYZ, MZX, MZY, MZYZ, MZZ
       DOUBLE PRECISION A(IP), B(IQ), AI(ICST), A2(IP*2), A2B(ICST),
      1                 AIB(ICST), Y(LL*2+1), CXX(LL*2+1), CXY(LL*2+1),
      2                 CYX(LL*2+1), CUZ(LL*2+1), CYU(LL*2+1),
@@ -964,6 +975,10 @@ cc      EQUIVALENCE (CYU(1),CYZ(1),CZX(1))
       INTEGER IP, IQ, IG, LL, ICST
       DOUBLE PRECISION X(IP+IQ), CYY(LL*2+1), G(IP+IQ), CXX0
 c local
+      INTEGER I, II, I1, IA, IB, IJ, IK, IAIB, IGAIB, IORIG, IGA2B,
+     1        IA2B, IPQ, IPM1, IQM1, I2P, L2, LXX, MXX, LXY, MXY, LYX,
+     2        MYX, LZX, MZX, LZY, MZY, LYZ, M2, MYZ, LUX, MUX, LUY, MUY,
+     3        LYU, MYU
       DOUBLE PRECISION A(IP), B(IQ), AI(ICST), A2(IP*2), A2B(ICST),
      1                 AIB(ICST), Y(LL*2+1), CXX(LL*2+1), CYX(LL*2+1),
      2                 CUY(LL*2+1), CYU(LL*2+1), CZY(LL*2+1), CST0, CST1
@@ -1119,6 +1134,7 @@ cxx      SUBROUTINE SDAV1(X,CYY,CXX0,G,C,IP,IQ,N,VD,NN,LL,ICST,IFG,LU)
 C      DADIDON'S (MINIMIZATION) PROCEDURE
 cxx      IMPLICIT REAL*8(A-H,O-Z)
 cc      COMMON /COM50/VD
+      INTEGER ISWRO
       COMMON /COM70/ISWRO
 cc      DIMENSION VD(50,50)
 cc      DIMENSION X(50),G(50),SX(50),SG(50),SR(50)
@@ -1130,6 +1146,7 @@ cxx      DIMENSION SX(IP+IQ),SG(IP+IQ),SR(IP+IQ)
       DOUBLE PRECISION X(IP+IQ), CYY(LL*2+1), CXX0, G(IP+IQ), C(IP+IQ),
      1                 VD(NN,NN)
 c local
+      INTEGER I, IG, ISPHAI, ITN, ITNS, IPHAI, IPQ, IPQ2, IRAM, J
       DOUBLE PRECISION SX(IP+IQ), SG(IP+IQ), SR(IP+IQ), CST0, CST1,
      1                 CST2, CST05, CONSTA, CONSTB, EPS1, EPS3, EPS4,
      2                 AIPQ, AN, PHAI, EPHAI1, T1, RO, RAM, RAMRO,
@@ -1308,6 +1325,7 @@ cxx      DIMENSION
       INTEGER K, L, M, LL
       DOUBLE PRECISION Y(LL*2+1), A(K), Z(LL*2+1)
 c local
+      INTEGER I, IJ, IORIG, IST, IEN, J
       DOUBLE PRECISION SUM
 cc      IORIG=501
       IORIG=LL+1
@@ -1334,6 +1352,8 @@ cc      DIMENSION Z(1001),Y(1001)
 cxx      DIMENSION Z(LL-L+1),Y(LL+M+1)
       INTEGER L, M, LL
       DOUBLE PRECISION Y(LL+M+1), Z(LL-L+1)
+c local
+      INTEGER I, IORIG, IST, IEN, IJ
 cc      IORIG=501
       IORIG=LL+1
       IST=IORIG+L
@@ -1360,6 +1380,7 @@ cxx      DIMENSION A(IP),B(IQ),X(ICST)
       INTEGER IP, IQ, IX, ICST, IG
       DOUBLE PRECISION A(IP), B(IQ), X(ICST)
 c local
+      INTEGER I, IH, IM1, IMJ, IPQ, J, JM, K, LH
       DOUBLE PRECISION CST0, GCONST, GAMMAX, SUM, GAM2
       CST0=0.0D-00
       IPQ=IP+IQ
