@@ -29,7 +29,8 @@ C         DFORM : INPUT FORMAT SPECIFICATION IN ONE CARD, FOR EXAMPLE,'(8
 C         (X(I),I=1,N) : ORIGINAL DATA.
 C
 C     NSG : NUMBER OF SEGMENTS OF FREQUENCY AXIS +1
-      PARAMETER (NSG=121)
+cxx      PARAMETER (NSG=121)
+      INTEGER, PARAMETER :: NSG=121
 C
 cxx      IMPLICIT REAL*8 (A-H,O-Z)
 cc      DIMENSION ACV0(101),ACV1(101),ACV2(101),COEF0(50),COEF1(50)
@@ -51,7 +52,8 @@ cxx      DIMENSION K01(NM),KOUNT2(NM)
       DOUBLE PRECISION DATA0(N), COEF0(LAGH,NM), VA0(NM), AIC0(NM),
      1                 DAIC21(NM), DAIC(NM), SXX(NSG,NM)
 c local
-      INTEGER IDX(5)
+      INTEGER I, II, IK0, IK1, IK5, IP0, IP1, IP2, J, JJ, KOUNT0,
+     1        KOUNT1, LAGH1, ML1, NI, NJ, NML, NSG1, IDX(5)
       DOUBLE PRECISION ACV0(LAGH+1), ACV1(LAGH+1), ACV2(LAGH+1),
      1                 COEF1(LAGH), COEF2(LAGH), DATA1(N), CN(LAGH+1),
      2                 AISTP, AIP0, AIP1, AIP2, CST2, CST4, ANI, ANJ,
@@ -364,6 +366,8 @@ cxx      DIMENSION CXX(L1),COEF(L1)
 cc	DIMENSION A(500),B(500)
       INTEGER L1, N, MO
       DOUBLE PRECISION CXX(L1), COEF(L1), OSD
+c local
+      INTEGER I, IM, L, LM, M, MP1
       DOUBLE PRECISION A(L1-1),B(L1-1), CST1, CST2, SD, AN, OAIC, SE,
      1                 D, D2, AM, DLSD, AIC
       CST1=1.0D-00
