@@ -37,6 +37,8 @@ cxx      DIMENSION R(LAGH1),PH(LAGH1),P(LAGH1,IP,IP)
       DOUBLE PRECISION P(LAGH1,IP,IP), P11(LAGH1), P22(LAGH1), C(LAGH1),
      1                 S(LAGH1), CP11(LAGH1), CP22(LAGH1), CC(LAGH1),
      2                 CS(LAGH1), R(LAGH1), PH(LAGH1)
+c local
+      INTEGER I
 C     INPUT / OUTPUT DATA FILE OPEN
 c      CALL SETWND
 c      CALL FLOPN2(NFL)
@@ -136,6 +138,8 @@ cxx      IMPLICIT REAL*8(A-H,O-Z)
 cxx      DIMENSION C(LAGH1),S(LAGH1),ARC(LAGH1)
       INTEGER LAGH1
       DOUBLE PRECISION C(LAGH1), S(LAGH1), ARC(LAGH1)
+c local
+      INTEGER I
       DOUBLE PRECISION PI, CST5
       PI=3.1415926536
       CST5=0.5D-00
@@ -176,6 +180,8 @@ cxx      IMPLICIT REAL*8(A-H,O-Z)
 cxx      DIMENSION CH(LAGH1),R(LAGH1)
       INTEGER N, LAGH1
       DOUBLE PRECISION CH(LAGH1), R(LAGH1)
+c local
+      INTEGER I, LAGH
       DOUBLE PRECISION D1, D2, CST0, CST1, CST100, E1, ER
 C     CONSTANTS D1,D2 COMPUTATION
       LAGH=LAGH1-1
@@ -207,6 +213,8 @@ cxx      IMPLICIT REAL*8(A-H,O-Z)
 cxx      DIMENSION ARC(LAGH1),PH(LAGH1)
       INTEGER LAGH1
       DOUBLE PRECISION ARC(LAGH1), PH(LAGH1)
+c local
+      INTEGER I
       DOUBLE PRECISION PI, PI2, DK
       PI=3.1415926536
       PI2=PI+PI
@@ -233,6 +241,7 @@ c      DIMENSION ARC(501)
 cxx      DIMENSION ARC(LAGH1)
       INTEGER LAGH1
       DOUBLE PRECISION C(LAGH1), S(LAGH1), PH(LAGH1)
+c local
       DOUBLE PRECISION ARC(LAGH1)
 C     ARCTANGENT COMPUTATION
       CALL SGLARC(C,S,ARC,LAGH1)
