@@ -23,7 +23,8 @@ C     BE ADDED TO FORM THE INPUT TO THIS PROGRAM.
 C     NRA: LENGTH OF WHITE NOISE RECORD TO BE GENERATED
 C
 cxx      IMPLICIT REAL*8(A-H,O-Z)
-      PARAMETER (MJ0=100)
+cxx      PARAMETER (MJ0=100)
+      INTEGER, PARAMETER :: MJ0=100
 cc      REAL*4 RANDOM
 ccc	 REAL*4	 RANDM
 cxx      REAL*8 RANDM
@@ -34,6 +35,8 @@ cxx      DIMENSION X1(MJ0,IR),X2(IR,NRA)
       INTEGER NRA, IR
       DOUBLE PRECISION SD1(IR,IR), X2(IR,NRA)
 c local
+      INTEGER I, I1, I2, I3, II, IIC, IM1, IND, IND1, J, JJ, K1, K2,
+     1        K3, K4
       DOUBLE PRECISION RANDM, SD(IR,IR), Y(IR), Z(IR), X1(MJ0,IR), CST0,
      1                 RC, RCONST, XX, SUM
 C     INPUT / OUTPUT DATA FILE OPEN
